@@ -2,7 +2,7 @@
  * includes/test.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -19,22 +19,23 @@
  */
 
 use super::{include, DebugIncluder, PageRef};
+use crate::settings::{WikitextMode, WikitextSettings};
 
 #[test]
 fn includes() {
-    let log = crate::build_logger();
+    let settings = WikitextSettings::from_mode(WikitextMode::Page);
 
     macro_rules! test {
         ($text:expr, $expected:expr $(,)?) => {{
             let mut text = str!($text);
-            let result = include(&log, &mut text, DebugIncluder, || panic!());
+            let result = include(&mut text, &settings, DebugIncluder, || panic!());
             let (output, actual) = result.expect("Fetching pages failed");
             let expected = $expected;
 
             println!("Input:  '{}'", $text);
-            println!("Output: '{}'", output);
-            println!("Pages (actual):   {:?}", actual);
-            println!("Pages (expected): {:?}", expected);
+            println!("Output: '{}'", &output);
+            println!("Pages (actual):   {:?}", &actual);
+            println!("Pages (expected): {:?}", &expected);
             println!();
 
             assert_eq!(
