@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/blockquote.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,15 +30,13 @@ pub const BLOCK_BLOCKQUOTE: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Parsing blockquote block"; "in-head" => in_head);
-
+    info!("Parsing blockquote block (in-head {in_head})");
     assert!(!flag_star, "Blockquote doesn't allow star flag");
     assert!(!flag_score, "Blockquote doesn't allow score flag");
     assert_block_name(&BLOCK_BLOCKQUOTE, name);
@@ -53,7 +51,7 @@ fn parse_fn<'r, 't>(
     let element = Element::Container(Container::new(
         ContainerType::Blockquote,
         elements,
-        arguments.to_attribute_map(),
+        arguments.to_attribute_map(parser.settings()),
     ));
 
     ok!(element, exceptions)
