@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/char.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -49,15 +49,13 @@ pub const BLOCK_CHAR: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Parsing character / HTML entity block"; "in-head" => in_head);
-
+    info!("Parsing character / HTML entity block (in-head {in_head})");
     assert!(!flag_star, "Char doesn't allow star flag");
     assert!(!flag_score, "Char doesn't allow score flag");
     assert_block_name(&BLOCK_CHAR, name);
