@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/checkbox.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,21 +30,13 @@ pub const BLOCK_CHECKBOX: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing checkbox block";
-        "in-head" => in_head,
-        "name" => name,
-        "star" => flag_star,
-    );
-
+    info!("Parsing checkbox block (name '{name}', in-head {in_head})");
     assert!(!flag_score, "Checkbox doesn't allow score flag");
     assert_block_name(&BLOCK_CHECKBOX, name);
 
@@ -53,7 +45,7 @@ fn parse_fn<'r, 't>(
 
     let element = Element::CheckBox {
         checked: flag_star,
-        attributes: arguments.to_attribute_map(),
+        attributes: arguments.to_attribute_map(parser.settings()),
     };
 
     ok!(element)
