@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/collapsible.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -31,19 +31,13 @@ pub const BLOCK_COLLAPSIBLE: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing collapsible block";
-        "in-head" => in_head,
-    );
-
+    info!("Parsing collapsible block (in-head {in_head})");
     assert!(!flag_star, "Collapsible doesn't allow star flag");
     assert!(!flag_score, "Collapsible doesn't allow score flag");
     assert_block_name(&BLOCK_COLLAPSIBLE, name);
@@ -71,7 +65,7 @@ fn parse_fn<'r, 't>(
     // Build element and return
     let element = Element::Collapsible {
         elements,
-        attributes: arguments.to_attribute_map(),
+        attributes: arguments.to_attribute_map(parser.settings()),
         start_open,
         show_text,
         hide_text,
@@ -98,7 +92,6 @@ fn parse_hide_location(s: &str, parser: &Parser) -> Result<(bool, bool), ParseWa
         }
     }
 
-    warn!(&parser.log(), "Unknown hideLocation argument"; "value" => s);
-
+    warn!("Unknown hideLocation argument '{s}'");
     Err(parser.make_warn(ParseWarningKind::BlockMalformedArguments))
 }
