@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/module/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -24,7 +24,6 @@ mod parser;
 mod rule;
 
 use super::prelude;
-use crate::log::prelude::*;
 use crate::parsing::rule::impls::block::Arguments;
 use crate::parsing::rule::{LineRequirement, Rule};
 use crate::parsing::{ParseResult, Parser};
@@ -60,7 +59,6 @@ impl ModuleRule {
     pub fn rule(&self) -> Rule {
         // Stubbed try_consume_fn implementation for the Rule.
         fn try_consume_fn<'p, 'r, 't>(
-            _: &Logger,
             _: &'p mut Parser<'r, 't>,
         ) -> ParseResult<'r, 't, Elements<'t>> {
             panic!("Pseudo rule for this module should not be executed directly!");
@@ -87,12 +85,10 @@ impl Debug for ModuleRule {
 /// Function pointer type to implement module parsing.
 ///
 /// The arguments are, in order:
-/// * `log` -- `Logger` instance
 /// * `parser` -- `Parser` instance
 /// * `name` -- The name of this module
 /// * `arguments` -- The arguments passed into the module
 pub type ModuleParseFn = for<'r, 't> fn(
-    &Logger,
     &mut Parser<'r, 't>,
     &'t str,
     Arguments<'t>,
