@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/module/modules/css.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,16 +27,14 @@ pub const MODULE_CSS: ModuleRule = ModuleRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     _arguments: Arguments<'t>,
 ) -> ParseResult<'r, 't, Option<Module<'t>>> {
-    info!(log, "Parsing categories module");
+    info!("Parsing categories module");
     assert_module_name(&MODULE_CSS, name);
 
     let css = parser.get_body_text(&BLOCK_MODULE)?;
     let exceptions = vec![ParseException::Style(cow!(css))];
-
     ok!(true; None, exceptions)
 }
