@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/radio.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,6 @@ pub const BLOCK_RADIO: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
@@ -38,13 +37,8 @@ fn parse_fn<'r, 't>(
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
     info!(
-        log,
-        "Parsing radio button block";
-        "in-head" => in_head,
-        "name" => name,
-        "star" => flag_star,
+        "Parsing radio button block (name '{name}', in-head {in_head}, star {flag_star})",
     );
-
     assert!(!flag_score, "Radio buttons don't allow score flag");
     assert_block_name(&BLOCK_RADIO, name);
 
@@ -54,7 +48,7 @@ fn parse_fn<'r, 't>(
     let element = Element::RadioButton {
         name: cow!(name),
         checked: flag_star,
-        attributes: arguments.to_attribute_map(),
+        attributes: arguments.to_attribute_map(parser.settings()),
     };
 
     ok!(element)
