@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/superscript.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -30,20 +30,13 @@ pub const BLOCK_SUPERSCRIPT: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing superscript block";
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing superscript block (name '{name}', in-head {in_head})");
     assert!(!flag_star, "Superscript doesn't allow star flag");
     assert!(!flag_score, "Superscript doesn't allow score flag");
     assert_block_name(&BLOCK_SUPERSCRIPT, name);
@@ -57,7 +50,7 @@ fn parse_fn<'r, 't>(
     let element = Element::Container(Container::new(
         ContainerType::Superscript,
         elements,
-        arguments.to_attribute_map(),
+        arguments.to_attribute_map(parser.settings()),
     ));
 
     ok!(paragraph_safe; element, exceptions)
