@@ -2,7 +2,7 @@
  * parsing/rule/impls/block/blocks/toc.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -31,28 +31,21 @@ pub const BLOCK_TABLE_OF_CONTENTS: BlockRule = BlockRule {
 };
 
 fn parse_fn<'r, 't>(
-    log: &Logger,
     parser: &mut Parser<'r, 't>,
     name: &'t str,
     flag_star: bool,
     flag_score: bool,
     in_head: bool,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(
-        log,
-        "Parsing table-of-contents block";
-        "in-head" => in_head,
-        "name" => name,
-    );
-
+    info!("Parsing table-of-contents block (name '{name}', in-head {in_head})");
+    parser.check_page_syntax()?;
     assert!(!flag_star, "Table of Contents doesn't allow star flag");
     assert!(!flag_score, "Table of Contents doesn't allow score flag");
     assert_block_name(&BLOCK_TABLE_OF_CONTENTS, name);
 
     let arguments = parser.get_head_map(&BLOCK_TABLE_OF_CONTENTS, in_head)?;
-    let attributes = arguments.to_attribute_map();
+    let attributes = arguments.to_attribute_map(parser.settings());
     let align = FloatAlignment::parse(name).map(|float| float.align);
     let element = Element::TableOfContents { align, attributes };
-
     ok!(false; element)
 }
