@@ -2,7 +2,7 @@
  * parsing/rule/impls/horizontal_rule.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -27,13 +27,10 @@ pub const RULE_HORIZONTAL_RULE: Rule = Rule {
 };
 
 fn try_consume_fn<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Consuming token to create a horizontal rule");
-
+    info!("Consuming token to create a horizontal rule");
     check_step(parser, Token::TripleDash)?;
     parser.get_optional_line_break()?;
-
     ok!(Element::HorizontalRule)
 }
