@@ -2,7 +2,7 @@
  * parsing/rule/impls/url.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -19,7 +19,7 @@
  */
 
 use super::prelude::*;
-use crate::tree::{LinkLabel, LinkLocation};
+use crate::tree::{LinkLabel, LinkLocation, LinkType};
 
 pub const RULE_URL: Rule = Rule {
     name: "url",
@@ -28,15 +28,14 @@ pub const RULE_URL: Rule = Rule {
 };
 
 fn try_consume_fn<'p, 'r, 't>(
-    log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    info!(log, "Consuming token as a URL");
-
+    info!("Consuming token as a URL");
     let token = parser.current();
     let url = cow!(token.slice);
 
     let element = Element::Link {
+        ltype: LinkType::Direct,
         link: LinkLocation::Url(url),
         label: LinkLabel::Url(None),
         target: None,
