@@ -2,7 +2,7 @@
  * render/html/element/container.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,55 +21,54 @@
 use super::prelude::*;
 use crate::tree::{Container, HtmlTag};
 
-pub fn render_container(log: &Logger, ctx: &mut HtmlContext, container: &Container) {
-    info!(log, "Rendering container"; "container" => container.ctype().name());
+pub fn render_container(ctx: &mut HtmlContext, container: &Container) {
+    info!("Rendering container '{}'", container.ctype().name());
 
     // Get HTML tag type for this type of container
     let tag_spec = container.ctype().html_tag(ctx);
 
+    // Get correct ID, based on the render setting
+    let random_id = choose_id(ctx, &tag_spec);
+
     // Build the tag
     let mut tag = ctx.html().tag(tag_spec.tag());
 
     // Merge the class attribute with the container's class, if it conflicts
     match tag_spec {
-        HtmlTag::Tag(_) => tag.attr(attr!(
-            "is" => "wj-container";;
-            container.attributes(),
-        )),
+        HtmlTag::Tag(_) => tag.attr(attr!(;; container.attributes())),
         HtmlTag::TagAndClass { class, .. } => tag.attr(attr!(
-            "is" => "wj-container",
             "class" => class;;
             container.attributes(),
         )),
         HtmlTag::TagAndId { id, .. } => tag.attr(attr!(
-            "is" => "wj-container",
-            "id" => &id;;
+            "id" => match random_id {
+                Some(ref id) => id,
+                None => &id,
+            };;
             container.attributes(),
         )),
     };
 
     // Add container internals
-    tag.inner(log, container.elements());
+    tag.inner(container.elements());
 }
 
-pub fn render_color(
-    log: &Logger,
-    ctx: &mut HtmlContext,
-    color: &str,
-    elements: &[Element],
-) {
-    info!(
-        log,
-        "Rendering color container";
-        "color" => color,
-        "elements-len" => elements.len(),
-    );
+pub fn render_color(ctx: &mut HtmlContext, color: &str, elements: &[Element]) {
+    info!("Rendering color container (color '{color}')");
 
     ctx.html()
         .span()
         .attr(attr!(
-            "is" => "wj-container",
             "style" => "color: " color ";",
         ))
-        .inner(log, elements);
+        .inner(elements);
+}
+
+fn choose_id(ctx: &mut HtmlContext, tag_spec: &HtmlTag) -> Option<String> {
+    // If we're in a situation where we want a randomly generated ID
+    if matches!(tag_spec, HtmlTag::TagAndId { .. }) && !ctx.settings().use_true_ids {
+        Some(ctx.random().generate_html_id())
+    } else {
+        None
+    }
 }
