@@ -2,7 +2,7 @@
  * render/html/element/iframe.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,37 +21,22 @@
 use super::prelude::*;
 use crate::tree::AttributeMap;
 
-pub fn render_iframe(
-    log: &Logger,
-    ctx: &mut HtmlContext,
-    url: &str,
-    attributes: &AttributeMap,
-) {
-    info!(
-        log,
-        "Rendering iframe block";
-        "url" => url,
-    );
+pub fn render_iframe(ctx: &mut HtmlContext, url: &str, attributes: &AttributeMap) {
+    info!("Rendering iframe block (url '{url}')");
 
     ctx.html().iframe().attr(attr!(
-        "is" => "wj-iframe",
         "src" => url,
         "crossorigin";;
         attributes
     ));
 }
 
-pub fn render_html(log: &Logger, ctx: &mut HtmlContext, contents: &str) {
-    info!(
-        log,
-        "Rendering html block (submitting to remote for iframe)";
-        "contents" => contents,
-    );
+pub fn render_html(ctx: &mut HtmlContext, contents: &str) {
+    info!("Rendering html block (submitting to remote for iframe)");
 
     // Submit HTML to be hosted on wjfiles, then get back its URL for the iframe.
-    let iframe_url = ctx.handle().post_html(log, ctx.info(), contents);
+    let iframe_url = ctx.handle().post_html(ctx.info(), contents);
     ctx.html().iframe().attr(attr!(
-        "is" => "wj-html",
         "src" => &iframe_url,
         "crossorigin",
     ));
