@@ -2,7 +2,7 @@
  * render/html/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -29,6 +29,7 @@ mod element;
 mod escape;
 mod meta;
 mod output;
+mod random;
 mod render;
 
 pub use self::meta::{HtmlMeta, HtmlMetaType};
@@ -39,10 +40,10 @@ use super::prelude;
 
 use self::attributes::AddedAttributes;
 use self::context::HtmlContext;
-use crate::log::prelude::*;
+use crate::data::PageInfo;
 use crate::render::{Handle, Render};
+use crate::settings::WikitextSettings;
 use crate::tree::SyntaxTree;
-use crate::PageInfo;
 
 #[derive(Debug)]
 pub struct HtmlRender;
@@ -52,17 +53,15 @@ impl Render for HtmlRender {
 
     fn render(
         &self,
-        log: &Logger,
-        page_info: &PageInfo,
         tree: &SyntaxTree,
+        page_info: &PageInfo,
+        settings: &WikitextSettings,
     ) -> HtmlOutput {
         info!(
-            log,
-            "Rendering syntax tree";
-            "target" => "html",
-            "site" => page_info.site.as_ref(),
-            "page" => page_info.page.as_ref(),
-            "category" => match &page_info.category {
+            "Rendering HTML (site {}, page {}, category {})",
+            page_info.site.as_ref(),
+            page_info.page.as_ref(),
+            match &page_info.category {
                 Some(category) => category.as_ref(),
                 None => "_default",
             },
@@ -71,6 +70,7 @@ impl Render for HtmlRender {
         let mut ctx = HtmlContext::new(
             page_info,
             &Handle,
+            settings,
             &tree.table_of_contents,
             &tree.footnotes,
         );
@@ -82,9 +82,9 @@ impl Render for HtmlRender {
 
         // Crawl through elements and generate HTML
         ctx.html()
-            .div()
+            .element("wj-body")
             .attr(attr!("class" => "wj-body"))
-            .inner(log, &tree.elements);
+            .inner(&tree.elements);
 
         // Build and return HtmlOutput
         ctx.into()
