@@ -2,7 +2,7 @@
  * render/html/test.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -23,11 +23,12 @@ use super::HtmlRender;
 
 #[test]
 fn html() {
-    let log = crate::build_logger();
     let page_info = PageInfo::dummy();
+    let settings = WikitextSettings::from_mode(WikitextMode::Page);
+
     let result = SyntaxTree::from_element_result(vec![], vec![], vec![], vec![], vec![]);
     let (tree, _) = result.into();
     if false {
-        let _output = HtmlRender.render(&log, &page_info, &tree);
+        let _output = HtmlRender.render(&tree, &page_info, &settings);
     }
 }
