@@ -2,7 +2,7 @@
  * render/null.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -32,16 +32,22 @@ impl Render for NullRender {
     type Output = ();
 
     #[inline]
-    fn render(&self, _log: &Logger, _page_info: &PageInfo, _tree: &SyntaxTree) {}
+    fn render(
+        &self,
+        _tree: &SyntaxTree,
+        _page_info: &PageInfo,
+        _settings: &WikitextSettings,
+    ) {
+    }
 }
 
 #[test]
 fn null() {
-    let log = crate::build_logger();
     let page_info = PageInfo::dummy();
+    let settings = WikitextSettings::from_mode(WikitextMode::Page);
     let result = SyntaxTree::from_element_result(vec![], vec![], vec![], vec![], vec![]);
     let (tree, _) = result.into();
-    let output = NullRender.render(&log, &page_info, &tree);
+    let output = NullRender.render(&tree, &page_info, &settings);
 
     assert_eq!(output, (), "Null render didn't produce the unit value");
 }
