@@ -2,7 +2,7 @@
  * render/text/context.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -18,10 +18,11 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+use crate::data::PageInfo;
 use crate::non_empty_vec::NonEmptyVec;
 use crate::render::Handle;
+use crate::settings::WikitextSettings;
 use crate::tree::{Element, VariableScopes};
-use crate::PageInfo;
 use std::fmt::{self, Write};
 use std::num::NonZeroUsize;
 
@@ -33,6 +34,7 @@ where
     output: String,
     info: &'i PageInfo<'i>,
     handle: &'h Handle,
+    settings: &'e WikitextSettings,
 
     //
     // Included page scopes
@@ -59,6 +61,9 @@ where
     /// added are instead replaced with spaces.
     invisible: usize,
 
+    /// The current equation index, for rendering.
+    equation_index: NonZeroUsize,
+
     /// The current footnote index, for rendering.
     footnote_index: NonZeroUsize,
 }
@@ -71,6 +76,7 @@ where
     pub fn new(
         info: &'i PageInfo<'i>,
         handle: &'h Handle,
+        settings: &'e WikitextSettings,
         table_of_contents: &'e [Element<'t>],
         footnotes: &'e [Vec<Element<'t>>],
     ) -> Self {
@@ -78,12 +84,14 @@ where
             output: String::new(),
             info,
             handle,
+            settings,
             variables: VariableScopes::new(),
             table_of_contents,
             footnotes,
             prefixes: Vec::new(),
             list_depths: NonEmptyVec::new(1),
             invisible: 0,
+            equation_index: NonZeroUsize::new(1).unwrap(),
             footnote_index: NonZeroUsize::new(1).unwrap(),
         }
     }
@@ -99,6 +107,11 @@ where
         self.info
     }
 
+    #[inline]
+    pub fn settings(&self) -> &WikitextSettings {
+        self.settings
+    }
+
     #[inline]
     pub fn language(&self) -> &str {
         &self.info.language
@@ -129,7 +142,12 @@ where
         self.footnotes
     }
 
-    #[inline]
+    pub fn next_equation_index(&mut self) -> NonZeroUsize {
+        let index = self.equation_index;
+        self.equation_index = NonZeroUsize::new(index.get() + 1).unwrap();
+        index
+    }
+
     pub fn next_footnote_index(&mut self) -> NonZeroUsize {
         let index = self.footnote_index;
         self.footnote_index = NonZeroUsize::new(index.get() + 1).unwrap();
