@@ -2,7 +2,7 @@
  * test/large.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -20,6 +20,7 @@
 
 use crate::data::PageInfo;
 use crate::parsing::{ParseWarningKind, Token};
+use crate::settings::{WikitextMode, WikitextSettings};
 use crate::tree::{Element, SyntaxTree};
 use std::borrow::Cow;
 
@@ -30,8 +31,8 @@ use std::borrow::Cow;
 /// also goes past serde_json's recursion limit, lol.
 #[test]
 fn recursion_depth() {
-    let log = crate::build_logger();
     let page_info = PageInfo::dummy();
+    let settings = WikitextSettings::from_mode(WikitextMode::Page);
 
     // Build wikitext input
     let mut input = String::new();
@@ -45,9 +46,9 @@ fn recursion_depth() {
     }
 
     // Run parser steps
-    crate::preprocess(&log, &mut input);
-    let tokens = crate::tokenize(&log, &input);
-    let (tree, warnings) = crate::parse(&log, &page_info, &tokens).into();
+    crate::preprocess(&mut input);
+    let tokens = crate::tokenize(&input);
+    let (tree, warnings) = crate::parse(&tokens, &page_info, &settings).into();
 
     // Check outputted warnings
     let warning = warnings.get(0).expect("No warnings produced");
@@ -73,8 +74,8 @@ fn recursion_depth() {
 fn large_payload() {
     const ITERATIONS: usize = 50;
 
-    let log = crate::build_logger();
     let page_info = PageInfo::dummy();
+    let settings = WikitextSettings::from_mode(WikitextMode::Page);
 
     // Build wikitext input
     let mut input = String::new();
@@ -98,9 +99,9 @@ In hac habitasse platea dictumst. Vestibulum fermentum libero nec erat porttitor
     }
 
     // Run parser steps
-    crate::preprocess(&log, &mut input);
-    let tokens = crate::tokenize(&log, &input);
-    let (_tree, warnings) = crate::parse(&log, &page_info, &tokens).into();
+    crate::preprocess(&mut input);
+    let tokens = crate::tokenize(&input);
+    let (_tree, warnings) = crate::parse(&tokens, &page_info, &settings).into();
 
     // Check output
     assert_eq!(warnings.len(), ITERATIONS * 3);
