@@ -2,7 +2,7 @@
  * test/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -19,6 +19,8 @@
  */
 
 mod ast;
+mod id_prefix;
 mod includer;
 mod large;
 mod prop;
+mod settings;
