@@ -2,7 +2,7 @@
  * text.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-use crate::log::prelude::*;
 use crate::parsing::ExtractedToken;
 
 /// Wrapper for the input string that was tokenized.
@@ -59,14 +58,12 @@ impl<'t> FullText<'t> {
     /// this function will panic.
     pub fn slice(
         &self,
-        log: &Logger,
         start_token: &ExtractedToken,
         end_token: &ExtractedToken,
     ) -> &'t str {
         let start = start_token.span.start;
         let end = end_token.span.end;
-
-        self.slice_impl(log, "full", start, end)
+        self.slice_impl("full", start, end)
     }
 
     /// Slices from the given start, but before the end token.
@@ -84,37 +81,21 @@ impl<'t> FullText<'t> {
     /// this function will panic.
     pub fn slice_partial(
         &self,
-        log: &Logger,
         start_token: &ExtractedToken,
         end_token: &ExtractedToken,
     ) -> &'t str {
         let start = start_token.span.start;
         let end = end_token.span.start;
-
-        self.slice_impl(log, "partial", start, end)
+        self.slice_impl("partial", start, end)
     }
 
-    fn slice_impl(
-        &self,
-        log: &Logger,
-        _slice_kind: &'static str,
-        start: usize,
-        end: usize,
-    ) -> &'t str {
-        info!(
-            log,
-            "Extracting {} slice from full text",
-            _slice_kind;
-            "start" => start,
-            "end" => end,
-        );
+    fn slice_impl(&self, slice_kind: &'static str, start: usize, end: usize) -> &'t str {
+        info!("Extracting {slice_kind} slice ({start}-{end}) from full text");
 
-        if start > end {
-            panic!(
-                "Starting index is later than the ending index: {} > {}",
-                start, end,
-            );
-        }
+        assert!(
+            start <= end,
+            "Starting index is later than the ending index: {start} > {end}",
+        );
 
         &self.text[start..end]
     }
@@ -124,7 +105,6 @@ impl<'t> FullText<'t> {
 fn slice() {
     use crate::parsing::Token;
 
-    let log = crate::build_logger();
     let text = "Apple banana!";
     let full_text = FullText::new(text);
 
@@ -139,14 +119,12 @@ fn slice() {
     }
 
     {
-        let slice = full_text.slice(&log, range!(0..1), range!(4..5));
-
+        let slice = full_text.slice(range!(0..1), range!(4..5));
         assert_eq!(slice, "Apple", "Full slice didn't match expected");
     }
 
     {
-        let slice = full_text.slice_partial(&log, range!(6..9), range!(12..13));
-
+        let slice = full_text.slice_partial(range!(6..9), range!(12..13));
         assert_eq!(slice, "banana", "Partial slice didn't match expected");
     }
 }
@@ -156,7 +134,6 @@ fn slice() {
 fn slice_invalid() {
     use crate::parsing::Token;
 
-    let log = crate::build_logger();
     let text = "Durian...";
     let full_text = FullText::new(text);
 
@@ -171,5 +148,5 @@ fn slice_invalid() {
     }
 
     // "Durian"
-    let _ = full_text.slice(&log, range!(6..7), range!(0..1));
+    let _ = full_text.slice(range!(6..7), range!(0..1));
 }
