@@ -2,7 +2,7 @@
  * tree/element/object.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -21,9 +21,9 @@
 use crate::data::PageRef;
 use crate::tree::clone::*;
 use crate::tree::{
-    Alignment, AnchorTarget, AttributeMap, ClearFloat, Container, FloatAlignment,
-    ImageSource, LinkLabel, LinkLocation, ListItem, ListType, Module, PartialElement,
-    Table, VariableMap,
+    Alignment, AnchorTarget, AttributeMap, ClearFloat, Container, Date,
+    DefinitionListItem, Embed, FloatAlignment, ImageSource, LinkLabel, LinkLocation,
+    LinkType, ListItem, ListType, Module, PartialElement, Tab, Table, VariableMap,
 };
 use ref_map::*;
 use std::borrow::Cow;
@@ -71,6 +71,9 @@ pub enum Element<'t> {
     /// An element representing an HTML table.
     Table(Table<'t>),
 
+    /// An element representing a tabview.
+    TabView(Vec<Tab<'t>>),
+
     /// An element representing an arbitrary anchor.
     ///
     /// This is distinct from link in that it maps to HTML `<a>`,
@@ -81,13 +84,23 @@ pub enum Element<'t> {
         elements: Vec<Element<'t>>,
     },
 
+    /// An element representing a named anchor.
+    ///
+    /// This is an area of the page that can be jumped to by name.
+    /// Associated syntax is `[[# name-of-anchor]]`.
+    AnchorName(Cow<'t, str>),
+
     /// An element linking to a different page.
     ///
     /// The "label" field is an optional field denoting what the link should
     /// display.
     ///
     /// The "link" field is either a page reference (relative URL) or full URL.
+    ///
+    /// The "ltype" field tells what kind of link produced this element.
     Link {
+        #[serde(rename = "type")]
+        ltype: LinkType,
         link: LinkLocation<'t>,
         label: LinkLabel<'t>,
         target: Option<AnchorTarget>,
@@ -113,6 +126,9 @@ pub enum Element<'t> {
         items: Vec<ListItem<'t>>,
     },
 
+    /// A definition list.
+    DefinitionList(Vec<DefinitionListItem<'t>>),
+
     /// A radio button.
     ///
     /// The "name" field translates to HTML, but is standard for grouping them.
@@ -180,6 +196,13 @@ pub enum Element<'t> {
         show_avatar: bool,
     },
 
+    /// A date display, showcasing a particular moment in time.
+    Date {
+        value: Date,
+        format: Option<Cow<'t, str>>,
+        hover: bool,
+    },
+
     /// Element containing colored text.
     ///
     /// The CSS designation of the color is specified, followed by the elements contained within.
@@ -194,6 +217,23 @@ pub enum Element<'t> {
         language: Option<Cow<'t, str>>,
     },
 
+    /// Element containing a named math equation.
+    #[serde(rename_all = "kebab-case")]
+    Math {
+        name: Option<Cow<'t, str>>,
+        latex_source: Cow<'t, str>,
+    },
+
+    /// Element containing inline math.
+    #[serde(rename_all = "kebab-case")]
+    MathInline { latex_source: Cow<'t, str> },
+
+    /// Element referring to an equation elsewhere in the page.
+    EquationReference(Cow<'t, str>),
+
+    /// An embedded piece of media or content from elsewhere.
+    Embed(Embed<'t>),
+
     /// Element containing a sandboxed HTML block.
     Html { contents: Cow<'t, str> },
 
@@ -264,10 +304,13 @@ impl Element<'_> {
             Element::Variable(_) => "Variable",
             Element::Email(_) => "Email",
             Element::Table(_) => "Table",
+            Element::TabView(_) => "TabView",
             Element::Anchor { .. } => "Anchor",
+            Element::AnchorName(_) => "AnchorName",
             Element::Link { .. } => "Link",
-            Element::List { .. } => "List",
             Element::Image { .. } => "Image",
+            Element::List { .. } => "List",
+            Element::DefinitionList(_) => "DefinitionList",
             Element::RadioButton { .. } => "RadioButton",
             Element::CheckBox { .. } => "CheckBox",
             Element::Collapsible { .. } => "Collapsible",
@@ -275,8 +318,13 @@ impl Element<'_> {
             Element::Footnote => "Footnote",
             Element::FootnoteBlock { .. } => "FootnoteBlock",
             Element::User { .. } => "User",
+            Element::Date { .. } => "Date",
             Element::Color { .. } => "Color",
             Element::Code { .. } => "Code",
+            Element::Math { .. } => "Math",
+            Element::MathInline { .. } => "MathInline",
+            Element::EquationReference(_) => "EquationReference",
+            Element::Embed(_) => "Embed",
             Element::Html { .. } => "HTML",
             Element::Iframe { .. } => "Iframe",
             Element::Include { .. } => "Include",
@@ -306,17 +354,26 @@ impl Element<'_> {
             | Element::Variable(_)
             | Element::Email(_) => true,
             Element::Table(_) => false,
-            Element::Anchor { .. } | Element::Link { .. } => true,
-            Element::List { .. } => false,
+            Element::TabView(_) => false,
+            Element::Anchor { .. } | Element::AnchorName(_) | Element::Link { .. } => {
+                true
+            }
             Element::Image { .. } => true,
+            Element::List { .. } => false,
+            Element::DefinitionList(_) => false,
             Element::RadioButton { .. } | Element::CheckBox { .. } => true,
             Element::Collapsible { .. } => false,
             Element::TableOfContents { .. } => false,
             Element::Footnote => true,
             Element::FootnoteBlock { .. } => false,
             Element::User { .. } => true,
+            Element::Date { .. } => true,
             Element::Color { .. } => true,
-            Element::Code { .. } => true,
+            Element::Code { .. } => false,
+            Element::Math { .. } => false,
+            Element::MathInline { .. } => true,
+            Element::EquationReference(_) => true,
+            Element::Embed(_) => false,
             Element::Html { .. } | Element::Iframe { .. } => false,
             Element::Include { paragraph_safe, .. } => *paragraph_safe,
             Element::LineBreak | Element::LineBreaks { .. } => true,
@@ -342,6 +399,9 @@ impl Element<'_> {
             Element::Variable(name) => Element::Variable(string_to_owned(name)),
             Element::Email(email) => Element::Email(string_to_owned(email)),
             Element::Table(table) => Element::Table(table.to_owned()),
+            Element::TabView(tabs) => {
+                Element::TabView(tabs.iter().map(|tab| tab.to_owned()).collect())
+            }
             Element::Anchor {
                 target,
                 attributes,
@@ -351,11 +411,14 @@ impl Element<'_> {
                 attributes: attributes.to_owned(),
                 elements: elements_to_owned(elements),
             },
+            Element::AnchorName(name) => Element::AnchorName(string_to_owned(name)),
             Element::Link {
+                ltype,
                 link,
                 label,
                 target,
             } => Element::Link {
+                ltype: *ltype,
                 link: link.to_owned(),
                 label: label.to_owned(),
                 target: *target,
@@ -380,6 +443,9 @@ impl Element<'_> {
                 alignment: *alignment,
                 attributes: attributes.to_owned(),
             },
+            Element::DefinitionList(items) => Element::DefinitionList(
+                items.iter().map(|item| item.to_owned()).collect(),
+            ),
             Element::RadioButton {
                 name,
                 checked,
@@ -426,6 +492,15 @@ impl Element<'_> {
                 name: string_to_owned(name),
                 show_avatar: *show_avatar,
             },
+            Element::Date {
+                value,
+                format,
+                hover,
+            } => Element::Date {
+                value: *value,
+                format: option_string_to_owned(format),
+                hover: *hover,
+            },
             Element::Color { color, elements } => Element::Color {
                 color: string_to_owned(color),
                 elements: elements_to_owned(elements),
@@ -434,6 +509,17 @@ impl Element<'_> {
                 contents: string_to_owned(contents),
                 language: option_string_to_owned(language),
             },
+            Element::Math { name, latex_source } => Element::Math {
+                name: option_string_to_owned(name),
+                latex_source: string_to_owned(latex_source),
+            },
+            Element::MathInline { latex_source } => Element::MathInline {
+                latex_source: string_to_owned(latex_source),
+            },
+            Element::EquationReference(name) => {
+                Element::EquationReference(string_to_owned(name))
+            }
+            Element::Embed(embed) => Element::Embed(embed.to_owned()),
             Element::Html { contents } => Element::Html {
                 contents: string_to_owned(contents),
             },
@@ -460,15 +546,3 @@ impl Element<'_> {
         }
     }
 }
-
-#[cfg(feature = "log")]
-impl slog::Value for Element<'_> {
-    fn serialize(
-        &self,
-        _: &slog::Record,
-        key: slog::Key,
-        serializer: &mut dyn slog::Serializer,
-    ) -> slog::Result {
-        serializer.emit_str(key, self.name())
-    }
-}
