@@ -2,7 +2,7 @@
  * wasm/mod.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -22,26 +22,26 @@
 mod macros;
 
 mod error;
-mod log;
 mod misc;
 mod page_info;
 mod parsing;
 mod preproc;
 mod render;
+mod settings;
 mod tokenizer;
 mod utf16;
 
 mod prelude {
-    pub use super::log::LOGGER;
     pub use wasm_bindgen::prelude::*;
     pub use wasm_bindgen::JsCast;
 }
 
-#[cfg(feature = "wasm-log")]
-pub use self::log::ConsoleLogger;
-
 pub use self::misc::version;
 pub use self::parsing::{parse, ParseOutcome, SyntaxTree};
 pub use self::preproc::preprocess;
-pub use self::render::{render_html, render_text};
+pub use self::render::render_text;
+pub use self::settings::WikitextSettings;
 pub use self::tokenizer::{tokenize, Tokenization};
+
+#[cfg(feature = "html")]
+pub use self::render::render_html;
