@@ -2,7 +2,7 @@
  * wasm/preproc.rs
  *
  * ftml - Library to parse Wikidot text
- * Copyright (C) 2019-2021 Wikijump Team
+ * Copyright (C) 2019-2022 Wikijump Team
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License as published by
@@ -22,8 +22,6 @@ use super::prelude::*;
 
 #[wasm_bindgen]
 pub fn preprocess(mut text: String) -> String {
-    let log = &*LOGGER;
-
-    crate::preprocess(log, &mut text);
+    crate::preprocess(&mut text);
     text
 }
